# DBCLASS
A Probabilistic Approach to Multiclass Classification with Unknown Instances


Use 'pip list --format=freeze > requirements.txt' to create/update requirements.txt file<br>
Use 'pip install -r requirements.txt' to install dependencies from requirements.txt file